==> cosmos-sdd-runtime-sdk-COSMOS-1.1.0-200904280331.zip: org/eclipse/cosmos/me/sdd/o10r/impl/RequirementsResolver.java <==
/***********************************************************************
 * Copyright (c) 2009 CA, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     CA, Inc. - Initial implementation
 ***********************************************************************/
package org.eclipse.cosmos.me.sdd.o10r.impl;

import javax.xml.bind.JAXBElement;
import javax.xml.namespace.QName;

import org.eclipse.cosmos.me.sdd.cr.ResourceHandler;
import org.eclipse.cosmos.me.sdd.schema.AlternativeRequirementType;
import org.eclipse.cosmos.me.sdd.schema.ConsumptionConstraintType;
import org.eclipse.cosmos.me.sdd.schema.InstallableUnitType;
import org.eclipse.cosmos.me.sdd.schema.PropertyConstraintType;
import org.eclipse.cosmos.me.sdd.schema.RequirementResourceConstraintType;
import org.eclipse.cosmos.me.sdd.schema.RequirementType;
import org.eclipse.cosmos.me.sdd.schema.RequirementsType;
import org.eclipse.cosmos.me.sdd.schema.ResourceType;
import org.eclipse.cosmos.me.sdd.schema.VersionConstraintType;
import org.eclipse.cosmos.me.sdd.schema.ext.SDDContext;

public class RequirementsResolver {
	private SDDContext ctxt;
	private ResourceHandler handler;
	
	public RequirementsResolver(SDDContext ctxt, ResourceHandler handler) {
		this.ctxt = ctxt;
		this.handler = handler;
	}
	
	public boolean installableUnitResolver() {
		InstallableUnitType iu = ctxt.getDeploymentDescriptor().getInstallableUnit();
		
		return resolve(iu.getRequirements());
	}

	private boolean resolve(RequirementsType requirements) {
		boolean result = true;
		if (requirements != null) {
			for (RequirementType req : requirements.getRequirement()) {
				result = result && resolve(req);
			}
		}
		return result;
	}

	private boolean resolve(RequirementType requirement) {
		boolean result = true;
		
		// at least one must be satisfied
		if (!requirement.getAlternative().isEmpty()) {
			boolean altResult = false;
			for (AlternativeRequirementType req : requirement.getAlternative()) {
				altResult = altResult || resolve(req);
			}
			result = result && altResult;
		}
		
		// all must be satisfied
		for (RequirementResourceConstraintType req : requirement.getResourceConstraint()) {
			result = result && resolve(req);
		}
		return result;
	}

	private boolean resolve(AlternativeRequirementType requirement) {
		boolean result = true;
		for (RequirementResourceConstraintType req : requirement.getResourceConstraint()) {
			result = result && resolve(req);
		}
		return result;
	}

	private boolean resolve(RequirementResourceConstraintType requirement) {
		boolean result = true;
		ResourceType rsrc = (ResourceType)requirement.getResourceRef();
		for (Object o : requirement.getResourceConstraintGroup()) {
			if (o instanceof JAXBElement) {
				Object value = ((JAXBElement<?>)o).getValue();
				if (value instanceof PropertyConstraintType) {
					result = result && resolve(rsrc, (PropertyConstraintType)value);
					continue;
				}
				if (value instanceof ConsumptionConstraintType) {
					result = result && resolve(rsrc, (ConsumptionConstraintType)value);
					continue;
				}
				if (value instanceof VersionConstraintType) {
					result = result && resolve(rsrc, (VersionConstraintType)value);
				}
			}
		}
		if (result) {
			requirement.getOtherAttributes().put(new QName("satisfied"), "true");
		}
		return result;
	}
	
	private boolean resolve(ResourceType rsrc, VersionConstraintType constraint) {
		boolean result = handler.evaluate(ctxt, rsrc, constraint);
		return result;
	}

	private boolean resolve(ResourceType rsrc, PropertyConstraintType constraint) {
		boolean result = handler.evaluate(ctxt, rsrc, constraint);
		return result;
	}
	
	private boolean resolve(ResourceType rsrc, ConsumptionConstraintType constraint) {
		boolean result = handler.evaluate(ctxt, rsrc, constraint);
		Long value = (Long)handler.getPropertyValue(ctxt, rsrc, constraint.getPropertyName());
		constraint.getValue().getOtherAttributes().put(new QName("actual"), value.toString());
		return result;
	}
}

==> cosmos-sdd-runtime-sdk-COSMOS-1.1.0-200905131057.zip: org/eclipse/cosmos/me/sdd/o10r/impl/RequirementsResolver.java <==
/***********************************************************************
 * Copyright (c) 2009 CA, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     CA, Inc. - Initial implementation
 *     SAS Institute - Bug 275669 
 ***********************************************************************/
package org.eclipse.cosmos.me.sdd.o10r.impl;

import javax.xml.bind.JAXBElement;
import javax.xml.namespace.QName;

import org.eclipse.cosmos.me.sdd.cr.ResourceHandler;
import org.eclipse.cosmos.me.sdd.schema.AlternativeRequirementType;
import org.eclipse.cosmos.me.sdd.schema.ConsumptionConstraintType;
import org.eclipse.cosmos.me.sdd.schema.InstallableUnitType;
import org.eclipse.cosmos.me.sdd.schema.PropertyConstraintType;
import org.eclipse.cosmos.me.sdd.schema.RequirementResourceConstraintType;
import org.eclipse.cosmos.me.sdd.schema.RequirementType;
import org.eclipse.cosmos.me.sdd.schema.RequirementsType;
import org.eclipse.cosmos.me.sdd.schema.ResourceType;
import org.eclipse.cosmos.me.sdd.schema.VersionConstraintType;
import org.eclipse.cosmos.me.sdd.schema.ext.SDDContext;

public class RequirementsResolver {
	private SDDContext ctxt;
	private ResourceHandler handler;
	public boolean results = false;
	RequirementResourceConstraintType unsatisified;
	
	public RequirementsResolver(SDDContext ctxt, ResourceHandler handler) {
		this.ctxt = ctxt;
		this.handler = handler;
	}
	
	public boolean installableUnitResolver() {
		InstallableUnitType iu = ctxt.getDeploymentDescriptor().getInstallableUnit();
		
		results = resolve(iu.getRequirements());
		return results;
	}

	private boolean resolve(RequirementsType requirements) {
		boolean result = true;
		if (requirements != null) {
			for (RequirementType req : requirements.getRequirement()) {
				result = result && resolve(req);
			}
		}
		return result;
	}

	private boolean resolve(RequirementType requirement) {
		boolean result = true;
		
		// at least one must be satisfied
		if (!requirement.getAlternative().isEmpty()) {
			boolean altResult = false;
			for (AlternativeRequirementType req : requirement.getAlternative()) {
				altResult = altResult || resolve(req);
			}
			result = result && altResult;
		}
		
		// all must be satisfied
		for (RequirementResourceConstraintType req : requirement.getResourceConstraint()) {
			result = result && resolve(req);
		}
		
		return result;
	}

	private boolean resolve(AlternativeRequirementType requirement) {
		boolean result = true;
		for (RequirementResourceConstraintType req : requirement.getResourceConstraint()) {
			result = result && resolve(req);
		}
		return result;
	}

	private boolean resolve(RequirementResourceConstraintType requirement) {
		boolean result = true;
		ResourceType rsrc = (ResourceType)requirement.getResourceRef();
		for (Object o : requirement.getResourceConstraintGroup()) {
			if (o instanceof JAXBElement) {
				Object value = ((JAXBElement<?>)o).getValue();
				if (value instanceof PropertyConstraintType) {
					result = result && resolve(rsrc, (PropertyConstraintType)value);
					continue;
				}
				if (value instanceof ConsumptionConstraintType) {
					result = result && resolve(rsrc, (ConsumptionConstraintType)value);
					continue;
				}
				if (value instanceof VersionConstraintType) {
					result = result && resolve(rsrc, (VersionConstraintType)value);
				}
			}
		}
		if (result) {
			requirement.getOtherAttributes().put(new QName("satisfied"), "true");
		}
		else {
			requirement.getOtherAttributes().put(new QName("satisfied"), "false");
		}
		return result;
	}
	
	private boolean resolve(ResourceType rsrc, VersionConstraintType constraint) {
		boolean result = handler.evaluate(ctxt, rsrc, constraint);
		return result;
	}

	private boolean resolve(ResourceType rsrc, PropertyConstraintType constraint) {
		boolean result = handler.evaluate(ctxt, rsrc, constraint);
		return result;
	}
	
	private boolean resolve(ResourceType rsrc, ConsumptionConstraintType constraint) {
		boolean result = handler.evaluate(ctxt, rsrc, constraint);
		Long value = (Long)handler.getPropertyValue(ctxt, rsrc, constraint.getPropertyName());
		constraint.getValue().getOtherAttributes().put(new QName("actual"), value.toString());
		return result;
	}

	public RequirementResourceConstraintType getUnsatisifiedResource() {
		InstallableUnitType iu = ctxt.getDeploymentDescriptor().getInstallableUnit();

		RequirementsType requirements = iu.getRequirements();
		if (requirements != null) {
			for (RequirementType requirement : requirements.getRequirement()) {
				for (AlternativeRequirementType req : requirement.getAlternative()) {
					for (RequirementResourceConstraintType req2 : req.getResourceConstraint()) {
						String value = req2.getOtherAttributes().get(new QName("satisified"));
						if("false".equals(value)) {
							return req2;
						}
					}
				}
				
				for (RequirementResourceConstraintType req : requirement.getResourceConstraint()) {
					String value = req.getOtherAttributes().get(new QName("satisified"));
					if("false".equals(value)) {
						return req;
					}
				}
			}
		}
		
		return null;
	}
}
